@@ -137,8 +137,8 @@ huge.mb = function(x, lambda = NULL, nlambda = NULL, lambda.min.ratio = NULL, sc
 		if(sym == "and")
 			fit$path[[i]] = sign(fit$path[[i]] * t(fit$path[[i]]))
 		fit$sparsity[i] = sum(fit$path[[i]])/d/(d-1)
-	}	
-   	rm(G,idx.tmp,ord,out)
+	}
+   	rm(G, out)
    	
    	fit$lambda = lambda
 
